#
# spec file for package python-proton-vpn-api-core
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-proton-vpn-api-core
Version:        0.35.5
Release:        1.1
Summary:        Proton VPN API library
License:        GPL-3.0-or-later
Group:          Development/Languages/Python
URL:            https://github.com/ProtonVPN/python-proton-vpn-api-core
Source:         https://github.com/ProtonVPN/python-proton-vpn-api-core/archive/refs/tags/v%{version}.tar.gz
BuildRequires:  %{python_module Jinja2}
BuildRequires:  %{python_module PyNaCl}
BuildRequires:  %{python_module cryptography}
BuildRequires:  %{python_module distro}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module proton-core}
BuildRequires:  %{python_module pytest-asyncio}
BuildRequires:  %{python_module pytest-cov}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module sentry-sdk}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
Requires:       python-Jinja2
Requires:       python-PyNaCl
Requires:       python-cryptography
Requires:       python-distro
Requires:       python-proton-core
Requires:       python-sentry-sdk
Conflicts:      python-proton-vpn-connection
Conflicts:      python-proton-vpn-killswitch
Conflicts:      python-proton-vpn-logger
BuildArch:      noarch
%python_subpackages

%description
This package contains a facade to the other Proton VPN components, exposing a uniform API for Proton VPN client.

%prep
%autosetup -p1 -n python-proton-vpn-api-core-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# See https://github.com/ProtonVPN/python-proton-vpn-api-core/issues/4
%pytest tests --deselect="tests/connection/test_vpnconfiguration.py"

%files %{python_files}
%license LICENSE
%doc README.md
%{python_sitelib}/proton
%{python_sitelib}/proton_vpn_api_core-%{version}*-info

%changelog
* Thu Oct 24 2024 Yunhe Guo <i@guoyunhe.me>
- Conflicts python-proton-vpn-connection
- Conflicts python-proton-vpn-killswitch
- Conflicts python-proton-vpn-logger
- Update to 0.35.5
  * Fix regression sending errors to sentry.
  * Fix to rpm package.spec, added accidentally removed Obsoletes statement.
  * Send all errors to sentry, but swallow api errors.
  * Merge logger package into this one.
  * Fix refregresion (logout user on 401 API error).
  * Catch and send LA errors to sentry.
  * Import refreshers from app.
  * Ensure there is a way to disable IPv6.
  * Change IPv6 default value and move out of the features dict.
  * Properly configure OpenVPN with IPv6 value.
  * Pass IPv6 value.
  * Put changes to fetching with timestamp (If-Modified-Since), behind a feature flag.
  * Fixes support for 'If-Modified-Since', expiration times.
  * Fixes support for 'If-Modified-Since' header in server list requests.
  * This adds support for 'If-Modified-Since' header in server list requests.
  * Make sure features cant be request after connection as well.
  * Expose property in VPNConnection to know if features can be applied on active connections.
  * Tier 0 level users can't control the features they have. So don't send any feature requests for them.
  * Fix crash after logout
  * Get rid of VPNConnectorWrapper.
  * Enable wireguard feature flag by default.
  * Handle UnicodeDecodeError when loading persisted VPN connection.
  * Update connection features via local agent if available.
  * Disconnect and notify the user when the maximum number of sessions is reached.
  * Handle ExpiredCertificate events.
  * Update default feature flags and update feature flags interface.
  * Update credentials in the background
  * Fix crash initializing VPN connector.
  * Update VPN credentials when an active VPN connection is found at startup.
  * Merge connection and kill switch packages into this one.
  * Improve testing to capture when default value is being passed.
  * Implement and expose feature flags.
  * Move local agent management into wireguard backend.
  * Send CPU architecture following semver's specs.
  * Switched over to async local agent api.
  * Attempt to use external local agent package, otherwise fallback to existent one.
  * Add the architecture in the appversion field for ProtonSSO.
  * Switch over to automatically generated changelogs for debian and rpm.
  * Fix sentry error sanitization crash.
  * Fix certificate duration regression.
  * Send wireguard certificate to server via local agent.
  * Increase certificate duration.
  * Refactor of Settings to ensure settings are only saved when they are changed.
  * Stop raising exceptions when getting wireguard certificate and it is expired.
* Wed May 22 2024 Alexandre Vicenzi <alexandre.vicenzi@suse.com>
- Update to 0.24.4
  * Filter OSError not just FileNotFound error in sentry.
  * Set the sentry user id based on a hash of /etc/machine-id
  * Fix deprecation warning when calculatin WireGuard certificate validity period.
  * Fix error saving cache file when parent directory does not exist
  * Only initialize sentry on first enable.
  * Forward SSL_CERT_FILE environment variable to sentry.
* Tue May  7 2024 Dirk Müller <dmueller@suse.com>
- update to 0.23.1:
  * Added missing pip dependencies.
  * Merged proton-vpn-api-session package into this one.
  * Pass requested features through to session login and two
    factor submit.
  * Provide method to update certificate.
  * Ensure that crash reporting state is preserved between
    restarts.
  * Explicitly state the sentry integrations we want. Dont
    include the ExceptHookIntegration
  * Change url for sentry, dont send server_name, use older
    sentry api
  * Add mechanism to send errors anonymously to sentry.
  * Return list of protocol plugins for a specific backend
    instead of returning a list of protocols names
  * Add WireGuard ports
* Thu Mar 21 2024 Yunhe Guo <i@guoyunhe.me>
- Update to version 0.21.0
  * Apply kill switch setting immediately
* Tue Mar 19 2024 Alexandre Vicenzi <alexandre.vicenzi@suse.com>
- Build for Leap
* Fri Feb  9 2024 Alexandre Vicenzi <alexandre.vicenzi@suse.com>
- Initial revision
